##==============================================================================================
##                                                                                            ##
##                             Batch Merge Subtitles with MKVMerge                            ##
##                                          By Miles                                          ##
##                   Idea from Iain McCain : https://superuser.com/a/1249870                  ##
##                                                                                            ##
##==============================================================================================
##                                                                                            ##
## Utilisation et conditions :                                                                ##
## - Il faut que les .srt et les .mkv soient dans le même dossier.                            ##
## - Il faut que les sous-titres externes .SRT aient le même nom de fichier que les .MKV.     ##
## - Il faut paramétrer l'extension des fichiers de sous-titres pour que ces derniers         ##
##      reflètent la langue : eng, fre,...                                                    ##
## - Il faudra par ailleurs modifier le code langage dans AudioLang_X et SubTrackLang_1       ##
## Il est possible de :                                                                       ##
## - spécifier des dossiers sources et destinations identiques ou différents                  ##
## - spécifier un titre de piste (pour toutes)                                                ##
##                                                                                            ##
##==============================================================================================
##                                                                                            ##
##                                         Objectifs :                                        ##
##    Remuxer deux MKV en gardant l'audio et le(s) sous-titre du premier ou un sous-titre     ##
##                        externe, et seulement la vidéo du second MKV                        ##
##                                                                                            ##
##==============================================================================================

Clear-Host

# Set MKVMerge.exe Path
$MKVMerge = "`"H:\z_MKV\mkvtoolnix\mkvmerge.exe`""
# For the parameters to pass to MKVMerge executable, will be construct

#Set Source and Target directories (Don't put an \ at the end)
$sourceDirectory_1 = "PATH_TO_SOURCE_1"
$sourceDirectory_2 = "PATH_TO_SOURCE_2"
$destinationDirectory = "PATH_TO_DESTINATION"

# Rename output file with this settings :
# $chain_to_search = '(\w+)\.S(\d{2})E(\d{2}).(.*)H264(.*)'
$chain_to_search = '(\w+)\.S(\d{2})E(\d{2})(.*)1080p.(.*)H.264(.*)'
# $chain__to_replace = '$1 - S$2E$3 - $4x265-10bits$5--Reencoded'
$chain__to_replace = '$1 (2021) - S$2E$3 - 1080p.$5x265-10bits$6--Reencoded'

# The filenames must be like : blabla.S00E00.blabla.H.264.blabla
# They will be renamed to : blabla - S00E00 - blabla.x265-10bits.blabla--Reencoded
# If you don't want the rename to be made, juste set to '' the variables.

# If there is no internal subtitles to keep :
# Set to $false for no internal subtitle
# Set to $true for one or more internal subtitles
$Internal_SUB = $true

# Is there an external subtitle ? Set the number of .SRT (0 - 2)
# It's exclusive, no internal SUB will be proceed..
$NB_External_SUB = 0

# Extension without the .
$MkvExtension = "mkv"
#Set Subtitle Extension (Don't add the . before the extension)
$SubExtension_1 = 'srt'
$SubExtension_2 = 'fre.srt'

#If source and destination are the same folder, set this to True, Otherwise let it to "False"
$merged_SUFFIX_name = "False"

# Move MKV1 (and SRT) to Not-Merged folder ? Set to $false or $true
$move_mkv1_after_merge = $true
# Move MKV2 (and SRT) to Not-Merged folder ? Set to $false or $true
$move_mkv1_after_merge = $true

# Initialization for those 2 variables, do not change them !
$MKVMerge_sub_param = ""
$MKVMerge_audio_param = ""
# ##################

#### FILE 1 - Keeping all but the video
# ================== AUDIO ==================
# Track 1 = Audio n°1
# Name and language of Audio Track n°1
$AudioTrackName_1 = "1:English - DDP 5.1"
$AudioLang_1 = "1:fr"
$AudioTrack_1_default = "1:yes"
# Define track order. Do not modify it unless you changed the track number in this section
$track_order = "1:0,0:1"
# $MKVMerge_audio_param = '--language', "$AudioLang_1", '--track-name', "$AudioTrackName_1", '--default-track', "$AudioTrack_1_default"
$MKVMerge_audio_param = "--language $AudioLang_1 --track-name `"$AudioTrackName_1`" --default-track $AudioTrack_1_default"

# # Track 2 = Audio n°2
# # Name and language of Audio Track n°2
# $AudioTrackName_1 = "2:English - DDP 5.1"
# $AudioLang_1 = "2:en"
# $AudioTrack_1_default = "2:yes"
# # Define track order. Do not modify it unless you changed the track number in this section
# $track_order = "1:0,0:1,0:2"
# $MKVMerge_audio_param += "--language $AudioLang_2 --track-name `"$AudioTrackName_2`" --default-track $AudioTrack_2_default"

##########################################
#### FILE 2 - MKV - Keeping only the video
#### $file_2_options = "--no-audio --no-track-tags --no-global-tags"

if ( $NB_External_SUB -ne 0 ) {
    # ================== EXTERNAL SUBTITLE ==================
    # Must have the same name as MKV1
    ####
    #### FILE 3 - SRT - Keeping all but the video (audio + chapters tags)
    # ================== SUBTITLES ==================
    # Track 0 = Sub n°1 to keep
    # Name and language of Subtitle Track n°0 + Sync Value
    $ExtSubTrackName_1 = "`"0:English - SRT`""
    $ExtSubTrackLang_1 = "0:eng"
    $ExtSubTrack_1_default = "0:yes"
    $ExtSub_charset_1 = "0:UTF-8"
    # Define track order
    $track_order += ",2:0"
    ####
    #### FILE 4 - SRT - Keeping all but the video (audio + chapters tags)
    # ================== SUBTITLES ==================
    # Track 0 = Sub n°1 to keep
    # Name and language of Subtitle Track n°0 + Sync Value
    $ExtSubTrackName_2 = "`"0:Français - SRT`""
    $ExtSubTrackLang_2 = "0:fr"
    $ExtSubTrack_2_default = "0:no"
    $ExtSub_charset_2 = "0:UTF-8"
    # Define track order
    if ( $NB_External_SUB -eq 2 ) {
        $track_order += ",3:0"
    }
}
else {
    # ================== INTERNAL SUBTITLES ==================
    if ( $Internal_SUB -eq $false ) {
        # Track 2 = Sub n°1 to keep
        # Name and language of Subtitle Track n°1 + Sync Value
        # $SubTrackName_1 = "2:English - SRT"
        # $SubTrackLang_1 = "2:en"
        # $SubTrack_1_default = "2:yes"
        # $sub_charset_1 = "2:UTF-8"
        # # Define track order
        # $track_order += ",0:2"
        # $subtitle_tracks = "2"
        # # $MKVMerge_sub_param = '--sub-charset', "$sub_charset_1", '--language', "$SubTrackLang_1", '--track-name', "$SubTrackName_1", '--default-track', "$SubTrack_1_default"
        # $MKVMerge_sub_param = "--sub-charset $sub_charset_1 --language $SubTrackLang_1 --track-name `"$SubTrackName_2`" --default-track $SubTrack_1_default"

        # Track 3 = Sub n°2 to keep
        # Name and language of Subtitle Track n°1 + Sync Value
        $SubTrackName_2 = "3:English SDH - SRT"
        $SubTrackLang_2 = "3:eng"
        $SubTrack_2_default = "3:yes"
        $sub_charset_2 = "3:UTF-8"
        # Define track order
        $track_order += ",0:3"
        $subtitle_tracks = "3"
        $MKVMerge_sub_param += "--sub-charset $sub_charset_2 --language $SubTrackLang_2 --track-name `"$SubTrackName_2`" --default-track $SubTrack_2_default"
        ####
    }
    else {
        # No internal subtitles are to be kept...
        $MKVMerge_sub_param = ""
    }
}
## End of part where there is something to change !
##==============================================================================================

# Testing if the Not-Merged folder already exists : if yes, it will be renamed, else it will be created.
$Path_Folder_NotMerged_2 = $sourceDirectory_2 + "\Not-Merged"
If(!(test-path $Path_Folder_NotMerged_2)) {
    New-Item -ItemType "Directory" -Force -Path $Path_Folder_NotMerged_2 -Verbose
} else {
    # Don't know what's the best... TO BE IMPROVED
    #Move-Item -Path $Path_Folder_NotMerged_2 -Destination "$sourceDirectory\Not-Merged--backup" -Verbose
    #Move-Item -Path $Path_Folder_NotMerged_2 -Destination "$sourceDirectory\Not-Merged--backup" -Verbose
}
# Testing if the Not-Merged folder already exists : if yes, it will be renamed, else it will be created.
$Path_Folder_NotMerged_1 = $sourceDirectory_1 + "\Not-Merged"
If(!(test-path $Path_Folder_NotMerged_1)) {
    New-Item -ItemType "Directory" -Force -Path $Path_Folder_NotMerged_1 -Verbose
} else {
    # Don't know what's the best... TO BE IMPROVED
    #Move-Item -Path $Path_Folder_NotMerged_2 -Destination "$sourceDirectory\Not-Merged--backup" -Verbose
    #Move-Item -Path $Path_Folder_NotMerged_2 -Destination "$sourceDirectory\Not-Merged--backup" -Verbose
}

#Process
$MKV_1_List = Get-ChildItem $sourceDirectory_1 -Filter "*.mkv" | ForEach-Object { $_.FullName } | Sort-Object
$Count_1 = $MKV_1_List.count
Write-Host "$Count_1 MKV's to be processed in $sourceDirectory_1."

$MKV_2_List = Get-ChildItem $sourceDirectory_2 -Filter "*.mkv" | ForEach-Object { $_.FullName } | Sort-Object
$Count_2 = $MKV_2_List.count
Write-Host "$Count_2 MKV's to be processed in $sourceDirectory_2."

# #########################
# Check if there is the same number of .srt files as .mkv files
if ( $NB_External_SUB -ne 0 ) {
    if ( $NB_External_SUB -ge 1 ) {     # If $NB_External_SUB >= 1 (include =1 and =2)
        $SRT_1_List = Get-ChildItem $sourceDirectory_1 -Filter "*.$SubExtension_1" | ForEach-Object { $_.FullName } | Sort-Object
        $Count_1_SRT = $SRT_1_List.count
        Write-Host "$Count_1 MKV's to be processed and $Count_1_SRT SRT's to be processed in $sourceDirectory_1."
        if ($Count_1 -eq $Count_1_SRT) {
            Write-Host "There is the same number of MKV and SRT n°1 files in this folder. Let's continue."
        } else {
            Write-Host "The number of MKV and SRT n°1 files isn't the same. ABORT..." -foreground "red"
            Exit
        }
    }
    
    if ( $NB_External_SUB -eq 2 ) {     # Only if $NB_External_SUB = 2
        $SRT_2_List = Get-ChildItem $sourceDirectory_1 -Filter "*.$SubExtension_2" | ForEach-Object { $_.FullName } | Sort-Object
        $Count_2_SRT = $SRT_2_List.count
        if ($Count_1 -eq $Count_2_SRT) {
            Write-Host "There is the same number of MKV and SRT n°2 files in this folder. Let's continue."
        } else {
            Write-Host "The number of MKV and SRT n°2 files isn't the same. ABORT..." -foreground "red"
            Exit
        }
    }
}
# #########################

# #########################
# Check if there is the same .mkv files in both source directory
if ($Count_1 -eq $Count_2) {
    Write-Host "There is the same number of MKV in the two sources folders. Let's continue."
} else {
    Write-Host "The number of MKV in the two sources folders isn't the same. ABORT..." -foreground "red"
    Exit
}
# if (!($Count_1 -eq ($filename_ep_final - $filename_ep_start + 1))) {
#     Write-Host "The number of episodes set in the script isn't the same as the number of files in the folders... EXITING NOW !" -foreground "red"
#     Exit
# }
# #########################
$compteur = 1

# for ($i = $filename_ep_start; $i -lt $filename_ep_final+1; $i++) {
Foreach ($MKV_1 in $MKV_1_List) {
    
    # Genreating File Name
    #       format = filename_1_part_1 + S + filename_season + E + i_counter + filename_1_part_2 + .mkv
    #       format = filename_2_part_1 + S + filename_season + E + i_counter + filename_2_part_2 + .mkv
    $FormatName_1 = (Get-Item $MKV_1).Basename
    $MKV_1_name = $FormatName_1.ToString()

    $MKV_2_file = get-ChildItem $sourceDirectory_2 -recurse | where {$_.name -like "*$MKV_1_name*"} | select name

    # Faire test si count = 1 -> ok      Sinon soucis !

    $FormatName_2 = $MKV_2_file.Name.ToString()
    $MKV_2_name = $FormatName_2.Substring(0,$FormatName_2.Length-($MkvExtension.Length+1))
    $MKV_2 = $sourceDirectory_2 + "\" + $MKV_2_name + ".$MkvExtension"

    # Title for the video track and for the destination file
    #$VideoTrackName = $MKV_1_name -replace '(.*).S(\d*)E(\d*).(.*)H.264(.*)', '$1 - S$2E$3 - $4x265-10bits$5--Reencoded'
    $VideoTrackName = $MKV_1_name -replace $chain_to_search, $chain__to_replace
    $VideoTrackName = "$VideoTrackName"

    #########################################################
    # Exceptions for some files with other than 2 SRT inside
    # You must copy paste the default entries set in the begining of this script in the Default section
    switch ($MKV_1_name)        
    {
        "Defiance.S03E01E02.720p.The World We Seize.HDTV.X264-DIMENSION"
        {
            # # ================== AUDIO ==================
            # # Track 1 = Audio n°1
            # # Name and language of Audio Track n°1
            # $AudioTrackName_1 = "1:English - DDP 5.1"
            # $AudioLang_1 = "1:en"
            # $AudioTrack_1_default = "1:yes"

            # # Only One subtitle track : n°2
            # $SubTrackName_1 = "3:English SDH - SRT"
            # $SubTrackLang_1 = "3:en"
            # $SubTrack_1_default = "3:yes"
            # $sub_charset_1 = "3:UTF-8"
            # # Define track order
            # $track_order = "1:0,0:1,0:3"
            # # Define subtitles track to keep
            # $subtitle_tracks = "3"

            $VideoTrackName = "Defiance - S03E01-E02 - 720p.HDTV.x265-10bits-DIMENSION--Reencoded"
            break
        }
        "Defiance.S02S02E12-E13.720p.All Things Must Pass--I Almost Prayed.HDTV.x264-KILLERS"
        {
            # # Track 1 = Audio n°1
            # # Name and language of Audio Track n°1
            # $AudioTrackName_1 = "1:English - AAC 2.0"
            # $AudioLang_1 = "1:en"
            # $AudioTrack_1_default = "1:yes"

            # # Only One subtitle track : n°2
            # $SubTrackName_1 = "2:English - SRT"
            # $SubTrackLang_1 = "2:en"
            # $SubTrack_1_default = "2:yes"
            # $sub_charset_1 = "2:UTF-8"
            # # Define track order
            # $track_order = "1:0,0:1,0:2"
            # # Define subtitles track to keep
            # $subtitle_tracks = "2"

            $VideoTrackName = "Defiance - S02S02E12-E13 - PROPER.720p.HDTV.x265-10bits-KILLERS--Reencoded"

            break
        }
        #Default state
        Default
        {
            # If not an exception, we don't want to modify the variables
            # $SubTrackName_1 = "3:English SDH - SRT"
            # $SubTrackLang_1 = "3:eng"
            # $SubTrack_1_default = "3:yes"
            # $sub_charset_1 = "3:UTF-8"
            # # Define track order
            # $track_order = "1:0,0:1,0:3"
            # # Define subtitles track to keep
            # $subtitle_tracks = "3"
            break
        }
    }
    #########################################################

    # Set Output File Name
    If ($merged_SUFFIX_name -eq "True") {
        $Output = $destinationDirectory + "\" + $VideoTrackName + '___MERGED' + '.mkv'
    } elseif ($merged_SUFFIX_name -eq "False") {
        # $Output = $destinationDirectory + "\" + $VideoTrackName + '.mkv'
        $Output = "$destinationDirectory" + "\" + "$VideoTrackName" + ".mkv"
    } else {
        write-host "Error in the value of the merged_SUFFIX_name variable. Current value = $merged_SUFFIX_name" -ForegroundColor "red"
        write-host "Should be set to True or False.`nScript is exiting now..." -ForegroundColor "white"
        Exit
    }
    # write-host "Output file will be :" -ForegroundColor "white"
    # write-host "$Output" -ForegroundColor "white"
    # write-host "--" -ForegroundColor "white"

    Write-Host "" -ForegroundColor "black" -BackgroundColor "white"
    Write-Host "Traitement du fichier n° $compteur / $Count_1..." -ForegroundColor "black" -BackgroundColor "white"
    Write-Host "" -ForegroundColor "black" -BackgroundColor "white"

    if ( $NB_External_SUB -ne 0 ) {
        
        # First external SRT to include
        $SRT_1_Name = $MKV_1_name + ".$SubExtension_1"
        $SRT_1 = $sourceDirectory_1 + "\" + $SRT_1_name

        $MKVMerge_param_start = "---output `"$Output`" --title `"$VideoTrackName`" --track-order `"$track_order`" --no-video --no-subtitles"
        $MKVMerge_param_mkv1 = "$MKVMerge_audio_param `"$MKV_1`""
        $MKVMerge_param_mkv2 = "--no-audio --no-track-tags --no-global-tags --language 0:en --track-name `"0:$VideoTrackName`" --default-track 0:yes --no-subtitles --no-audio `"$MKV_2`""
        
        $MKVMerge_param_srt1 = "--sub-charset $Extsub_charset_1 --language $ExtSubTrackLang_1 --track-name `"$ExtSubTrackName_1`" --default-track $ExtSubTrack_1_default `"$SRT_1`""
        
        $MKVMerge_param_srt_all = "$MKVMerge_param_srt1"

        if ( $NB_External_SUB -ne 0 ) {
            # Second external SRT to include
            $SRT_2_Name = $MKV_1_name + ".$SubExtension_2"
            $SRT_2 = $sourceDirectory_1 + "\" + $SRT_2_name
            
            $MKVMerge_param_srt2 = "--sub-charset $Extsub_charset_2 --language $ExtSubTrackLang_2 --track-name `"$ExtSubTrackName_2`" --default-track $ExtSubTrack_2_default `"$SRT_2`""
            $MKVMerge_param_srt_all += " $MKVMerge_param_srt2"
        }

        $MKVMerge_param_all = "$MKVMerge_param_start  $MKVMerge_param_mkv1 $MKVMerge_param_mkv2 $MKVMerge_param_srt_all"

    } 
    else {
        # INTERNAL SUB to keep
        $MKVMerge_param_start = "--output `"$Output`" --title `"$VideoTrackName`" --track-order `"$track_order`" --subtitle-tracks $subtitle_tracks  --no-video"
        if ( $Internal_SUB -eq $true ) {
            # There is some internal subtitles to keep
            $MKVMerge_param_mkv1 = "$MKVMerge_audio_param $MKVMerge_sub_param `"$MKV_1`""
        }
        else {
            # There is no internal subtitles to keep
            $MKVMerge_param_mkv1 = "$MKVMerge_audio_param `"$MKV_1`""
        }
        $MKVMerge_param_mkv2 = "--no-audio --no-track-tags --no-global-tags --language 0:en --track-name `"0:$VideoTrackName`" --default-track 0:yes --no-subtitles --no-audio `"$MKV_2`""

        $MKVMerge_param_all = "$MKVMerge_param_start  $MKVMerge_param_mkv1 $MKVMerge_param_mkv2"

        # ##################
        # Debug
        # Write-Host "$MKVMerge_param_start" -ForegroundColor "black" -BackgroundColor "DarkGray"
        # Write-Host "$MKVMerge_audio_param" -ForegroundColor "black" -BackgroundColor "DarkGray"
        # Write-Host "$MKVMerge_sub_param" -ForegroundColor "black" -BackgroundColor "DarkGray"
        # Write-Host "$MKVMerge_param_mkv2" -ForegroundColor "black" -BackgroundColor "DarkGray"
        # Write-Host "" -ForegroundColor "black" -BackgroundColor "DarkGray"
        # Write-Host "$MKVMerge_param_all" -ForegroundColor "black" -BackgroundColor "DarkGray"
        # Write-Host "" -ForegroundColor "black" -BackgroundColor "DarkGray"
        # Write-Host "Commande qui sera lancée :" -ForegroundColor "black" -BackgroundColor "DarkGray"

        # Write-Host "& $MKVMerge" "$MKVMerge_param_all" -ForegroundColor "black" -BackgroundColor "DarkGray"
        # ##################
    }
    
    # Last step to command construction
    $command = "& $MKVMerge $MKVMerge_param_all"
    # Launch begin...
    Invoke-Expression $command

    Write-Host "" -ForegroundColor "black" -BackgroundColor "white"
    Write-Host "Fin du traitement du fichier n° $compteur / $Count_1." -ForegroundColor "black" -BackgroundColor "white"
    Write-Host "" -ForegroundColor "black" -BackgroundColor "white"

    If (Test-Path $Output) {
        #Clean Up
        #Remove-Item $MKV
        #Remove-Item $Sub
        #Remove-Item $OtherSub
        # Move to folder Not-Merged, this folder's existence has already been tested, and the folder is created.
        if ( $move_mkv1_after_merge -eq $true ) {
            Move-Item -Path $MKV_1 -Destination $Path_Folder_NotMerged_1 -Verbose
            if ( $NB_External_SUB -ne 0 ) {
                Move-Item -Path $SRT_1 -Destination $Path_Folder_NotMerged_1 -Verbose
                if ( $NB_External_SUB -eq 2 ) {
                    Move-Item -Path $SRT_2 -Destination $Path_Folder_NotMerged_2 -Verbose
                }
            }
        }
        if ( $move_mkv2_after_merge -eq $true ) {
            Move-Item -Path $MKV_2 -Destination $Path_Folder_NotMerged_2 -Verbose
        }        
    }
    Else {
        write-host "File NON-EXISTANT - $Output" -foreground "red"
        "File NON-EXISTANT - $Output" | Out-File "$destinationDirectory\Errors.txt" -Append
    }
    $compteur++
}



# ##############################
# Command History
#
# internal Subtitles :
# two subtiles to keep :
#& $MKVMerge --title "$VideoTrackName" --track-order "$track_order" --subtitle-tracks "$subtitle_tracks" -o "$Output" --no-video --language "$AudioLang_1" --track-name "$AudioTrackName_1" --default-track "$AudioTrack_1_default" --sub-charset "$sub_charset_1" --language "$SubTrackLang_1" --track-name "$SubTrackName_1" --default-track "$SubTrack_1_default" --sub-charset "$sub_charset_2" --language "$SubTrackLang_2" --track-name "$SubTrackName_2" --default-track "$SubTrack_2_default" "$MKV_1" --no-audio --no-track-tags --no-global-tags --language "0:en" --track-name "0:$VideoTrackName" --default-track "0:yes" --no-subtitles --no-audio "$MKV_2"

# Only one subtitles to keep
# & $MKVMerge --title "$VideoTrackName" --track-order "$track_order" --subtitle-tracks "$subtitle_tracks" -o "$Output" --no-video --language "$AudioLang_1" --track-name "$AudioTrackName_1" --default-track "$AudioTrack_1_default" --sub-charset "$sub_charset_1" --language "$SubTrackLang_1" --track-name "$SubTrackName_1" --default-track "$SubTrack_1_default" "$MKV_1" --no-audio --no-track-tags --no-global-tags --language "0:en" --track-name "0:$VideoTrackName" --default-track "0:yes" --no-subtitles --no-audio "$MKV_2"
#
#
# External Subtitles 
# # 1 SRT
# & $MKVMerge --output "$Output" --title "$VideoTrackName" --track-order "$track_order" --no-video --no-subtitles --language "$AudioLang_1" --track-name "$AudioTrackName_1" --default-track "$AudioTrack_1_default" "$MKV_1" --no-audio --no-track-tags --no-global-tags --language "0:en" --track-name "0:$VideoTrackName" --default-track "0:yes" "$MKV_2" --sub-charset "$Extsub_charset_1" --language "$ExtSubTrackLang_1" --track-name "$ExtSubTrackName_1" --default-track "$ExtSubTrack_1_default" "$SRT_1"
#
# # 2 SRTs
# & $MKVMerge --title "$VideoTrackName" --track-order "$track_order" -o "$Output" --no-video --no-subtitles --language "$AudioLang_1" --track-name "$AudioTrackName_1" --default-track "$AudioTrack_1_default" --language "$AudioLang_1" --track-name "$AudioTrackName_1" --default-track "$AudioTrack_1_default" "$MKV_1" --no-audio --no-track-tags --no-global-tags --language "0:en" --track-name "0:$VideoTrackName" --default-track "0:yes" "$MKV_2" --sub-charset "$ExtSub_charset_1" --language "$ExtSubTrackLang_1" --track-name "$ExtSubTrackName_1" --default-track "$ExtSubTrack_1_default" "$SRT_1" --sub-charset "$ExtSub_charset_2" --language "$ExtSubTrackLang_2" --track-name "$ExtSubTrackName_2" --default-track "$ExtSubTrack_2_default" "$SRT_2"